import { RegionType, ApiCredentials } from '@tencent-serverless-framework/common';
import { Client } from 'tencentcloud-sdk-nodejs/tencentcloud/services/postgres/v20170312/postgres_client';
import { PostgresqlDeployInputs, PostgresqlDeployOutputs, PostgresqlRemoveInputs } from './interface';
import { CreateServerlessDBInstanceRequest, ServerlessDBAccount, ServerlessDBInstance, ServerlessDBInstanceNetInfo } from 'tencentcloud-sdk-nodejs/tencentcloud/services/postgres/v20170312/postgres_models';
/** Postgresql （Postgresql 数据库）for serverless component */
export declare class Postgresql {
    /** 地域 */
    region: RegionType;
    /** 鉴权信息 */
    credentials: ApiCredentials;
    /** sdk 实例 */
    client: Client;
    /**
     * Postgresql for serverless component 构造函数，返回 client
     *
     * @param credentials 认证信息
     * @param region 区域
     */
    constructor(credentials: ApiCredentials | undefined, region: RegionType);
    /**
     * 部署 postgresql 实例
     *
     * @param inputs  输入
     * @returns 部署结果
     */
    deploy(inputs?: PostgresqlDeployInputs): Promise<PostgresqlDeployOutputs>;
    /**
     * 移除 postgresql 实例
     *
     * @param inputs 移除 postgresql 实例输入
     * @returns 移除结果，成功返回 {}
     */
    remove(inputs?: PostgresqlRemoveInputs): Promise<{}>;
    /**
     * 通过数据库名称获取实例
     *
     * @param dBInstanceName 数据库名称
     * @returns 数据库详情
     */
    getDbInstanceDetail(dBInstanceName: string): Promise<ServerlessDBInstance | undefined>;
    /**
     * 获取数据库是否允许外部访问
     *
     * @param netInfos 数据库网络信息
     * @returns 数据库是否允许外网访问
     */
    getDbExtranetAccess(netInfos: ServerlessDBInstanceNetInfo[]): boolean;
    /**
     * 设置数据库外网访问
     *
     * @param dBInstanceName 数据库实例名称
     * @param extranetAccess 设置是否有外网访问权限
     * @returns 返回数据库详情
     */
    toggleDbInstanceAccess(dBInstanceName: string, extranetAccess: boolean): Promise<ServerlessDBInstance | undefined>;
    /**
     * 创建数据库实例
     *
     * @param postgresInputs 创建实例输入参数
     * @returns 返回数据库详情
     */
    createDbInstance(postgresInputs: CreateServerlessDBInstanceRequest): Promise<ServerlessDBInstance | undefined>;
    /**
     * 删除数据库实例
     *
     * @param dBInstanceName 数据库实例名称
     * @returns 返回删除后的实例信息，如成功为 undefined
     */
    deleteDbInstance(dBInstanceName: string): Promise<ServerlessDBInstance | undefined>;
    /**
     * 格式化数据库连接串
     *
     * @param netInfo 数据库网络信息
     * @param accountInfo 数据库账户信息
     * @param dbName 数据库名称
     * @returns 返回数据库连接串 object
     */
    formatPgUrl(netInfo: ServerlessDBInstanceNetInfo, accountInfo: ServerlessDBAccount, dbName: string): {
        connectionString: string;
        host: string;
        port: number;
        user: string;
        password: string;
        dbname: string;
    };
}
